capture_cache

Function capture_cache 

pub fn capture_cache(
    pager: &mut dyn CachePager,
    blobs: &dyn BlobStore,
) -> Result<Digest256>
Capture the entire live state of pager into the supplied blobs store.

Returns the digest of the crate::format::PageManifest blob; this is the value that goes into the .pfimg manifest’s cache.manifest field.

Pauses the pager for the duration of the capture and resumes on the way out — even if a page read errors midway through.